==> dl.php?src=linea21_1_0.zip: linea21/workshop/sup.php <==
<?
include_once("../lib/lib_common.php"); 

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////  
if (!IsSuperAdmin())
ReloadIndex('admin');  
////////////

$link_det=$rub_link."&amp;todo=det&amp;id=".$id; 

if(isset($_POST['valider'])) {
	$workshop_object = new workshop;
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	$result=$workshop_object->DeleteWorkshop($id, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);
if(count($result)>1) exit();
$workshop_denomination=FormatTitleh2($result[0]['workshop_denomination']);

?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['workshop']?></a>
		</li>
		<li>
			<span><? echo formatnavTitle($GLOBALS['lang']['workshop']['sup']." : ". $workshop_denomination); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php afflinkbar($todo,$id, $lang); ?>
<? echo "<h2>".$workshop_denomination."</h2>"; ?>
<form id="supworkshop" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<div class="info" id="truetransfert1">
<?php echo $GLOBALS['lang']['workshop']['sup_workshop_warning']; ?>
</div>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<? echo cancel_button($rub_link."&amp;todo=det&amp;id=".$id); ?>
<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>

==> dl.php?src=linea21_1_3.zip: linea21/workshop/sup.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage workshop
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

include_once("../lib/lib_common.php"); 

if(isset($_POST['id']))	$id=$_POST['id'];
if(isset($_GET['id']))	$id=$_GET['id'];

//////////// Check Inclusion de pages //////////// 
if (!function_exists('AuthenthificationProcess')){ 
include_once("../lib/lib_common.php");
ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////  
if (!IsSuperAdmin())
ReloadIndex('admin');  
////////////

$link_det=$rub_link."&amp;todo=det&amp;id=".$id; 

if(isset($_POST['valider'])) {
	$workshop_object = new workshop;
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	$result=$workshop_object->DeleteWorkshop($id, $sql_object);
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

$req_det= SQL_getoneCompleteWorkshop($id);
$result=$sql_object->DBSelect($req_det);
if(count($result)>1) exit();
$workshop_denomination=FormatTitleh2($result[0]['workshop_denomination']);

?>
<div id="chemin">
	<ul>
		<li>
			<a href="index.php" class="chemin_home"><? echo _t('way','home') ?></a>
		</li>
		<li>
			   <a href="<?php echo $rub_link; ?>" id="chemin_<? echo $rub; ?>" class="chemin_rub"><? echo _t('menu','workshop')?></a>
		</li>
		<li>
			<span><? echo formatnavTitle(_t('workshop','sup')." : ". $workshop_denomination); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once(THEME_ADMIN_PATH."quickicons.php");
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
<?php afflinkbar($todo,$id, $lang); ?>
<? echo "<h2>".$workshop_denomination."</h2>"; ?>
<form id="supworkshop" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
<div class="info" id="truetransfert1">
<?php echo _t('workshop','sup_workshop_warning'); ?>
</div>
<div>
<input name="id" type="hidden" value="<?php echo $id; ?>" />
<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
<? echo cancel_button($rub_link."&amp;todo=det&amp;id=".$id); ?>
<input name="valider" type="submit" value="<? echo _t('btn','valid') ?>" class="button" id="valider" />
</div>
</form>
</div>
<?php include_once($dir."/help.php"); ?>
</div>
